package org.peimari.jfreechart.test;

import javax.servlet.annotation.WebServlet;

import com.vaadin.annotations.Theme;
import com.vaadin.annotations.VaadinServletConfiguration;
import com.vaadin.server.VaadinRequest;
import com.vaadin.server.VaadinServlet;
import com.vaadin.ui.UI;
import com.vaadin.ui.VerticalLayout;
import java.awt.BasicStroke;
import java.awt.Color;
import org.jfree.chart.ChartFactory;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.plot.CategoryPlot;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.chart.plot.ValueMarker;
import org.jfree.chart.renderer.category.BarRenderer;
import org.jfree.chart.renderer.category.StandardBarPainter;
import org.jfree.data.category.DefaultCategoryDataset;
import org.jfree.ui.RectangleAnchor;
import org.vaadin.addon.JFreeChartWrapper;

/**
 * This UI is the application entry point. A UI may either represent a browser window 
 * (or tab) or some part of a html page where a Vaadin application is embedded.
 * <p>
 * The UI is initialized using {@link #init(VaadinRequest)}. This method is intended to be 
 * overridden to add component to the user interface and initialize non-component functionality.
 */
@Theme("mytheme")
public class MyUI extends UI {

    @Override
    protected void init(VaadinRequest vaadinRequest) {
        final VerticalLayout layout = new VerticalLayout();
        
  DefaultCategoryDataset dataset = new DefaultCategoryDataset();
	    dataset.setValue(48.0, "2018", "Q1");
	    dataset.setValue(40.0, "2019", "Q1");
	    dataset.setValue(28.0, "2018", "Q2");
	    dataset.setValue(28.0, "2019", "Q2");
	    dataset.setValue(39.0, "2018", "Q3");
	    dataset.setValue(60.0, "2019", "Q3");
	    dataset.setValue(40.0, "2018", "Q4");
	    dataset.setValue(29.0, "2019", "Q4");
	    
	    
	    JFreeChart chart = ChartFactory.createBarChart(
	        "Physical Activity", 
	        "Quarter",
	        "Points",
	        dataset,
	        PlotOrientation.VERTICAL,
	        true, 
	        true,
	        false
	    );
	    
	    ValueMarker marker = new ValueMarker(35.0);  // position is the value on the axis
	    marker.setPaint(Color.yellow);
	    marker.setStroke( new BasicStroke(2.0f));
	    marker.setLabel("Threshold One");
	    marker.setLabelAnchor(RectangleAnchor.CENTER);
	    
	    ValueMarker markerTwo = new ValueMarker(58.0);  // position is the value on the axis
	    markerTwo.setPaint(Color.yellow);
	    markerTwo.setStroke( new BasicStroke(2.0f));
	    markerTwo.setLabel("Threshold Two");
	    markerTwo.setLabelAnchor(RectangleAnchor.CENTER);
	    
	    CategoryPlot plot = chart.getCategoryPlot();
	    plot.addRangeMarker(marker);
	    plot.addRangeMarker(markerTwo);
	    
	    BarRenderer renderer = (BarRenderer) plot.getRenderer();
	    ((BarRenderer) plot.getRenderer()).setBarPainter(new StandardBarPainter());
	    
	    Color color = null;
	    
	    for (int i = 0; i < dataset.getRowCount(); i++){
	        switch (i) {
	        case 0:
	        	// green
	        	
	        	renderer.setSeriesPaint(0, color.GREEN);
	            break;
	        case 1:
	            // blue	        
	            renderer.setSeriesPaint(1, color.BLUE);
	            break;
	            
	        }
	    }
	    JFreeChartWrapper wrapper = new JFreeChartWrapper(chart);
	    /*{

	    	@Override
            public void attach() {
                super.attach();
                Resource r = getSource();
                setResource("src", r);
            }
	    };*/
	    
	    layout.addComponent(wrapper);
	    //System.out.println("wrapper: " + wrapper);
            
            
        setContent(layout);
    }

    @WebServlet(urlPatterns = "/*", name = "MyUIServlet", asyncSupported = true)
    @VaadinServletConfiguration(ui = MyUI.class, productionMode = false)
    public static class MyUIServlet extends VaadinServlet {
    }
}
